==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiCore/QPropertyBindingData_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qpropertyprivate.h>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qproperty.h>
#include "utils_p.h"

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QtPrivate_QPropertyBindingData(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QtPrivate::QPropertyBindingData")
    QtPrivate::QPropertyBindingData *_ptr = reinterpret_cast<QtPrivate::QPropertyBindingData *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QPropertyBindingData()
void __qt_construct_QtPrivate_QPropertyBindingData_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPropertyBindingData()")
    Q_UNUSED(__java_arguments)
    QtPrivate::QPropertyBindingData *__qt_this = new(__qtjambi_ptr) QtPrivate::QPropertyBindingData();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QtPrivate::QPropertyBindingData
void __qt_destruct_QtPrivate_QPropertyBindingData(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QtPrivate::QPropertyBindingData")
    reinterpret_cast<QtPrivate::QPropertyBindingData*>(ptr)->~QPropertyBindingData();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QtPrivate::QPropertyBindingData::QPropertyBindingData()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyBindingData_initialize_1native__Lio_qt_core_QPropertyBindingData_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QtPrivate::QPropertyBindingData::QPropertyBindingData()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QtPrivate_QPropertyBindingData_0, sizeof(QtPrivate::QPropertyBindingData), typeid(QtPrivate::QPropertyBindingData), false, &deleter_QtPrivate_QPropertyBindingData, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QtPrivate::QPropertyBindingData::evaluateIfDirty(const QUntypedPropertyData*)const
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyBindingData_evaluateIfDirty_1native_1const_1QUntypedPropertyData_1ptr_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        const QtPrivate::QPropertyBindingData *__qt_this = QtJambiAPI::objectFromNativeId<QtPrivate::QPropertyBindingData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QtPrivate::QPropertyBindingData::evaluateIfDirty(const QUntypedPropertyData*)const", __qt_this)
        const QUntypedPropertyData* __qt_arg__1 = QtJambiAPI::objectFromNativeId<QUntypedPropertyData>(arg__1);
        __qt_this->evaluateIfDirty(__qt_arg__1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QtPrivate::QPropertyBindingData::hasBinding()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyBindingData_hasBinding_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QtPrivate::QPropertyBindingData *__qt_this = QtJambiAPI::objectFromNativeId<QtPrivate::QPropertyBindingData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QtPrivate::QPropertyBindingData::hasBinding()const", __qt_this)
        __java_return_value = __qt_this->hasBinding();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QtPrivate::QPropertyBindingData::isNotificationDelayed()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyBindingData_isNotificationDelayed_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QtPrivate::QPropertyBindingData *__qt_this = QtJambiAPI::objectFromNativeId<QtPrivate::QPropertyBindingData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QtPrivate::QPropertyBindingData::isNotificationDelayed()const", __qt_this)
        __java_return_value = __qt_this->isNotificationDelayed();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QtPrivate::QPropertyBindingData::notifyObservers(QUntypedPropertyData*)const
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyBindingData_notifyObservers_1native_1QUntypedPropertyData_1ptr_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID propertyDataPtr0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        const QtPrivate::QPropertyBindingData *__qt_this = QtJambiAPI::objectFromNativeId<QtPrivate::QPropertyBindingData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QtPrivate::QPropertyBindingData::notifyObservers(QUntypedPropertyData*)const", __qt_this)
        QUntypedPropertyData* __qt_propertyDataPtr0 = QtJambiAPI::objectFromNativeId<QUntypedPropertyData>(propertyDataPtr0);
        __qt_this->notifyObservers(__qt_propertyDataPtr0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QtPrivate::QPropertyBindingData::notifyObservers(QUntypedPropertyData*,QBindingStorage*)const
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyBindingData_notifyObservers_1native_1QUntypedPropertyData_1ptr_1QBindingStorage_1ptr_1constfct__JJJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID propertyDataPtr0,
 QtJambiNativeID storage1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        const QtPrivate::QPropertyBindingData *__qt_this = QtJambiAPI::objectFromNativeId<QtPrivate::QPropertyBindingData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QtPrivate::QPropertyBindingData::notifyObservers(QUntypedPropertyData*,QBindingStorage*)const", __qt_this)
        QUntypedPropertyData* __qt_propertyDataPtr0 = QtJambiAPI::objectFromNativeId<QUntypedPropertyData>(propertyDataPtr0);
        QBindingStorage* __qt_storage1 = QtJambiAPI::objectFromNativeId<QBindingStorage>(storage1);
        __qt_this->notifyObservers(__qt_propertyDataPtr0, __qt_storage1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QtPrivate::QPropertyBindingData::registerWithCurrentlyEvaluatingBinding()const
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyBindingData_registerWithCurrentlyEvaluatingBinding_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        const QtPrivate::QPropertyBindingData *__qt_this = QtJambiAPI::objectFromNativeId<QtPrivate::QPropertyBindingData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QtPrivate::QPropertyBindingData::registerWithCurrentlyEvaluatingBinding()const", __qt_this)
        __qt_this->registerWithCurrentlyEvaluatingBinding();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QtPrivate::QPropertyBindingData::removeBinding()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyBindingData_removeBinding_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QtPrivate::QPropertyBindingData *__qt_this = QtJambiAPI::objectFromNativeId<QtPrivate::QPropertyBindingData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QtPrivate::QPropertyBindingData::removeBinding()", __qt_this)
        __qt_this->removeBinding();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QtPrivate::QPropertyBindingData::setBinding(QUntypedPropertyBinding,QUntypedPropertyData*,QtPrivate::QPropertyObserverCallback,QtPrivate::QPropertyBindingWrapper)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyBindingData_setBinding_1native_1cref_1QUntypedPropertyBinding_1QUntypedPropertyData_1ptr_1QtPrivate_1QPropertyObserverCallback_1QtPrivate_1QPropertyBindingWrapper__JJJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID newBinding0,
 QtJambiNativeID propertyDataPtr1)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QtPrivate::QPropertyBindingData *__qt_this = QtJambiAPI::objectFromNativeId<QtPrivate::QPropertyBindingData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QtPrivate::QPropertyBindingData::setBinding(QUntypedPropertyBinding,QUntypedPropertyData*,QtPrivate::QPropertyObserverCallback,QtPrivate::QPropertyBindingWrapper)", __qt_this)
        const QUntypedPropertyBinding& __qt_newBinding0 = QtJambiAPI::valueReferenceFromNativeId<QUntypedPropertyBinding>(newBinding0);
        QUntypedPropertyData* __qt_propertyDataPtr1 = QtJambiAPI::objectFromNativeId<QUntypedPropertyData>(propertyDataPtr1);
        QtPrivate::QPropertyObserverCallback __qt_staticObserverCallback2 = qtjambi_get_signal_callback(__jni_env, __qt_propertyDataPtr1);
        QtPrivate::QPropertyBindingWrapper __qt_bindingWrapper3 = nullptr;
        QUntypedPropertyBinding __qt_return_value = __qt_this->setBinding(__qt_newBinding0, __qt_propertyDataPtr1, __qt_staticObserverCallback2, __qt_bindingWrapper3);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QtPrivate_QPropertyBindingData(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QtPrivate::QPropertyBindingData>("QtPrivate::QPropertyBindingData", "io/qt/core/QPropertyBindingData");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QtPrivate_QPropertyBindingData, {
        ConstructorInfo(&__qt_construct_QtPrivate_QPropertyBindingData_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QtPrivate_QPropertyBindingData);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiCore/QPropertyBindingData_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qpropertyprivate.h>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qproperty.h>
#include "utils_p.h"

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QtPrivate_QPropertyBindingData(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QtPrivate::QPropertyBindingData")
    QtPrivate::QPropertyBindingData *_ptr = reinterpret_cast<QtPrivate::QPropertyBindingData *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QPropertyBindingData()
void __qt_construct_QtPrivate_QPropertyBindingData(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPropertyBindingData()")
    Q_UNUSED(__java_arguments)
    QtPrivate::QPropertyBindingData *__qt_this = new(__qtjambi_ptr) QtPrivate::QPropertyBindingData();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QtPrivate::QPropertyBindingData::QPropertyBindingData()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyBindingData_initialize_1native__Lio_qt_core_QPropertyBindingData_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QtPrivate::QPropertyBindingData::QPropertyBindingData()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QtPrivate_QPropertyBindingData, sizeof(QtPrivate::QPropertyBindingData), typeid(QtPrivate::QPropertyBindingData), false, &deleter_QtPrivate_QPropertyBindingData, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QtPrivate::QPropertyBindingData
void __qt_destruct_QtPrivate_QPropertyBindingData(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QtPrivate::QPropertyBindingData")
    reinterpret_cast<QtPrivate::QPropertyBindingData*>(ptr)->~QPropertyBindingData();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QtPrivate::QPropertyBindingData::evaluateIfDirty(const QUntypedPropertyData*)const
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyBindingData_evaluateIfDirty_1native_1const_1QUntypedPropertyData_1ptr_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        const QtPrivate::QPropertyBindingData *__qt_this = QtJambiAPI::objectFromNativeId<QtPrivate::QPropertyBindingData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QtPrivate::QPropertyBindingData::evaluateIfDirty(const QUntypedPropertyData*)const", __qt_this)
        const QUntypedPropertyData* __qt_arg__1 = QtJambiAPI::objectFromNativeId<QUntypedPropertyData>(arg__1);
        __qt_this->evaluateIfDirty(__qt_arg__1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QtPrivate::QPropertyBindingData::hasBinding()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyBindingData_hasBinding_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QtPrivate::QPropertyBindingData *__qt_this = QtJambiAPI::objectFromNativeId<QtPrivate::QPropertyBindingData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QtPrivate::QPropertyBindingData::hasBinding()const", __qt_this)
        __java_return_value = __qt_this->hasBinding();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QtPrivate::QPropertyBindingData::isNotificationDelayed()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyBindingData_isNotificationDelayed_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QtPrivate::QPropertyBindingData *__qt_this = QtJambiAPI::objectFromNativeId<QtPrivate::QPropertyBindingData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QtPrivate::QPropertyBindingData::isNotificationDelayed()const", __qt_this)
        __java_return_value = __qt_this->isNotificationDelayed();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QtPrivate::QPropertyBindingData::notifyObservers(QUntypedPropertyData*)const
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyBindingData_notifyObservers_1native_1QUntypedPropertyData_1ptr_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID propertyDataPtr0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        const QtPrivate::QPropertyBindingData *__qt_this = QtJambiAPI::objectFromNativeId<QtPrivate::QPropertyBindingData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QtPrivate::QPropertyBindingData::notifyObservers(QUntypedPropertyData*)const", __qt_this)
        QUntypedPropertyData* __qt_propertyDataPtr0 = QtJambiAPI::objectFromNativeId<QUntypedPropertyData>(propertyDataPtr0);
        __qt_this->notifyObservers(__qt_propertyDataPtr0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QtPrivate::QPropertyBindingData::notifyObservers(QUntypedPropertyData*,QBindingStorage*)const
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyBindingData_notifyObservers_1native_1QUntypedPropertyData_1ptr_1QBindingStorage_1ptr_1constfct__JJJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID propertyDataPtr0,
 QtJambiNativeID storage1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        const QtPrivate::QPropertyBindingData *__qt_this = QtJambiAPI::objectFromNativeId<QtPrivate::QPropertyBindingData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QtPrivate::QPropertyBindingData::notifyObservers(QUntypedPropertyData*,QBindingStorage*)const", __qt_this)
        QUntypedPropertyData* __qt_propertyDataPtr0 = QtJambiAPI::objectFromNativeId<QUntypedPropertyData>(propertyDataPtr0);
        QBindingStorage* __qt_storage1 = QtJambiAPI::objectFromNativeId<QBindingStorage>(storage1);
        __qt_this->notifyObservers(__qt_propertyDataPtr0, __qt_storage1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QtPrivate::QPropertyBindingData::registerWithCurrentlyEvaluatingBinding()const
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyBindingData_registerWithCurrentlyEvaluatingBinding_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        const QtPrivate::QPropertyBindingData *__qt_this = QtJambiAPI::objectFromNativeId<QtPrivate::QPropertyBindingData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QtPrivate::QPropertyBindingData::registerWithCurrentlyEvaluatingBinding()const", __qt_this)
        __qt_this->registerWithCurrentlyEvaluatingBinding();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QtPrivate::QPropertyBindingData::removeBinding()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyBindingData_removeBinding_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QtPrivate::QPropertyBindingData *__qt_this = QtJambiAPI::objectFromNativeId<QtPrivate::QPropertyBindingData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QtPrivate::QPropertyBindingData::removeBinding()", __qt_this)
        __qt_this->removeBinding();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QtPrivate::QPropertyBindingData::setBinding(QUntypedPropertyBinding,QUntypedPropertyData*,QtPrivate::QPropertyObserverCallback,QtPrivate::QPropertyBindingWrapper)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyBindingData_setBinding_1native_1cref_1QUntypedPropertyBinding_1QUntypedPropertyData_1ptr_1QtPrivate_1QPropertyObserverCallback_1QtPrivate_1QPropertyBindingWrapper__JJJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID newBinding0,
 QtJambiNativeID propertyDataPtr1)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QtPrivate::QPropertyBindingData *__qt_this = QtJambiAPI::objectFromNativeId<QtPrivate::QPropertyBindingData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QtPrivate::QPropertyBindingData::setBinding(QUntypedPropertyBinding,QUntypedPropertyData*,QtPrivate::QPropertyObserverCallback,QtPrivate::QPropertyBindingWrapper)", __qt_this)
        const QUntypedPropertyBinding& __qt_newBinding0 = QtJambiAPI::valueReferenceFromNativeId<QUntypedPropertyBinding>(newBinding0);
        QUntypedPropertyData* __qt_propertyDataPtr1 = QtJambiAPI::objectFromNativeId<QUntypedPropertyData>(propertyDataPtr1);
        QtPrivate::QPropertyObserverCallback __qt_staticObserverCallback2 = qtjambi_get_signal_callback(__jni_env, __qt_propertyDataPtr1);
        QtPrivate::QPropertyBindingWrapper __qt_bindingWrapper3 = nullptr;
        QUntypedPropertyBinding __qt_return_value = __qt_this->setBinding(__qt_newBinding0, __qt_propertyDataPtr1, __qt_staticObserverCallback2, __qt_bindingWrapper3);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QtPrivate_QPropertyBindingData(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QtPrivate::QPropertyBindingData>("QtPrivate::QPropertyBindingData", "io/qt/core/QPropertyBindingData");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QtPrivate_QPropertyBindingData, {
        ConstructorInfo(&__qt_construct_QtPrivate_QPropertyBindingData, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QtPrivate_QPropertyBindingData);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
